@@ -2,7 +2,7 @@
 
 #include "R_qz_global.h"
 
-SEXP R_dtgsen(SEXP IJOB, SEXP WANTQ, SEXP WANTZ, SEXP SELECT,
+SEXP R_dtgsen(SEXP IJOB, SEXP IWANTQ, SEXP IWANTZ, SEXP ISELECT,
 		SEXP N, SEXP S, SEXP LDA, SEXP T, SEXP LDB,
 		SEXP ALPHAR, SEXP ALPHAI, SEXP BETA,
 		SEXP Q, SEXP LDQ, SEXP Z, SEXP LDZ,
@@ -37,8 +37,8 @@ SEXP R_dtgsen(SEXP IJOB, SEXP WANTQ, SEXP WANTZ, SEXP SELECT,
 	Memcpy(REAL(Z_OUT), REAL(Z), total_length);
 
 	/* Call Fortran. */
-	F77_CALL(dtgsen)(INTEGER(IJOB), INTEGER(WANTQ), INTEGER(WANTZ),
-		INTEGER(SELECT), INTEGER(N), REAL(S_OUT), INTEGER(LDA),
+	F77_CALL(wdtgsen)(INTEGER(IJOB), INTEGER(IWANTQ), INTEGER(IWANTZ),
+		INTEGER(ISELECT), INTEGER(N), REAL(S_OUT), INTEGER(LDA),
 		REAL(T_OUT), INTEGER(LDB),
 		REAL(ALPHAR), REAL(ALPHAI), REAL(BETA),
 		REAL(Q_OUT), INTEGER(LDQ), REAL(Z_OUT), INTEGER(LDZ),
